import os
from pathlib import Path
from tempfile import TemporaryDirectory
import unittest

import sbol3
from sbol_utilities.graph_sbol import graph_sbol

from helpers import assert_files_identical

# Path to load SBOL files from
TESTFILE_DIR = Path(__file__).parent / 'test_files'


class GraphSbol(unittest.TestCase):
    def test_dotfile_generation(self):
        """
        Tests by creating and comparing dot file generated by graphviz with an existing proper file
        """
        # Load SBOL file
        doc = sbol3.Document()
        doc.read(str(TESTFILE_DIR / 'BBa_J23101.nt'))
        with TemporaryDirectory() as tmp:
            out_stem = Path(tmp) / 'out'
            graph_sbol(doc, file_format="pdf", view_now=False, outfile=str(out_stem), write_source=True)

            # compare generated file and file expected
            generated_file = out_stem.with_suffix('.dot')
            proper_file = TESTFILE_DIR / 'BBa_J23101.dot'
            assert_files_identical(generated_file, proper_file)

            # check that a substantive PDF has been created (> 10kb)
            self.assertGreater(os.path.getsize(str(out_stem.with_suffix('.pdf'))), 10000)


if __name__ == '__main__':
    unittest.main()
